@@ -6,8 +6,6 @@
 #include <glib-object.h>
 #include <libgweather/weather.h>
 
-#include "clock-zonetable.h"
-
 G_BEGIN_DECLS
 
 #define CLOCK_LOCATION_TYPE         (clock_location_get_type ())
@@ -59,7 +57,8 @@ void clock_location_set_coords (ClockLocation *loc, gfloat latitude, gfloat long
 void clock_location_localtime (ClockLocation *loc, struct tm *tm);
 
 gboolean clock_location_is_current (ClockLocation *loc);
-void clock_location_make_current (ClockLocation *loc, 
+void clock_location_make_current (ClockLocation *loc,
+				  guint          transient_parent_xid,
 				  GFunc          callback,
 				  gpointer       data,
 				  GDestroyNotify destroy);
